@@ -5,7 +5,7 @@
 from typing import Any
 import pygame as pg
 
-from . import types, Draw, Event, ValuedNode, Pos
+from . import types, Draw, ValuedNode, Pos
 
 
 class Checkbox(ValuedNode):
@@ -28,7 +28,7 @@ class Checkbox(ValuedNode):
             return False
         kwargs.setdefault('value', False)
         ValuedNode.__init__(self, **kwargs)
-        self.add_processor(Event.ON_CLICKUP, click_event)
+        self.add_processor('on-click-up', click_event)
 
     def can_grab_focus(self) -> bool:
         return True
