@@ -4,7 +4,7 @@
 """Definition of class Node."""
 
 from __future__ import annotations
-from typing import Tuple, Optional, Callable, List, Iterator, TYPE_CHECKING
+from typing import Tuple, Optional, List, Iterator, TYPE_CHECKING
 from typing import Union, Any, Dict, Type
 import re
 import inspect
@@ -12,12 +12,14 @@ import logging
 import pygame as pg
 
 from .animations import FadeAnimation, FadeInAnimation, FadeOutAnimation
-from .animations import GlowAnimation, GrowAnimation, ScrollAnimation
-from . import types, Media, Style, Event, Pos, Draw, Util, NodeType
-from . import Status, StyleClass
+from .animations import FillAnimation, GlowAnimation, GrowAnimation
+from .animations import PopInAnimation, PopOutAnimation, ScrollAnimation
+from .style import INHERITED, DEFAULT
+from . import types, Media, Pos, Draw, Util, NodeType, StyleClass
 
 if TYPE_CHECKING:
-    from . import EventManager, Window, WindowSystem, Animation
+    from .event_manager import _EventManager
+    from . import Animation, Window
 
 
 class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
@@ -48,6 +50,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         'font',
         'font-size',
         'halign',
+        'opacity',
         'padding',
         'pos',
         'pos-list',
@@ -77,21 +80,20 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         self.__size: types.opt_pos_opt_t = None
         self.__parent: Optional[Node] = None
         self.__container_size: types.opt_pos_t = None
-        self.__events: Dict[str, List[types.event_proc_t]] = dict()
-        self.__style_procs: Dict[str, List[types.event_proc_t]] = dict()
-        self.__link: Optional[Callable[[], bool]] = None
+        self.__events: Dict[types.event_t, List[types.event_proc_t]] = dict()
+        self.__style_procs: Dict[types.event_t, List[types.event_proc_t]]
+        self.__style_procs = dict()
+        self.__link: Optional[types.link_t] = None
         self.__link_proc: Optional[types.event_proc_t] = None
-        self.__manager: Optional['EventManager'] = None
+        self.__manager: Optional['_EventManager'] = None
         self.__prev_flags: int = 0
-        self.__style_cache: Dict[str, Any] = dict()
+        self.__style_cache: types.style_t = dict()
         self.__has_ctx_menu: bool = False
         self.__animation: Optional['Animation'] = None
 
         #  build node style classes
         style = kwargs.get('style')
-        my_stc = StyleClass(self, register=False)
-        if style is not None:
-            my_stc.add(style)
+        my_stc = StyleClass(self, register=False, style=style)
         stc = kwargs.get('stc', list())
         if stc is None:
             stc = list()
@@ -121,12 +123,12 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         return self.__parent
 
     @property
-    def manager(self) -> Optional[EventManager]:
+    def manager(self) -> Optional[_EventManager]:
         """Get the event manager of self."""
         return self.__manager
 
     @property
-    def manager_(self) -> EventManager:
+    def manager_(self) -> _EventManager:
         """Get the event manager of self + check result is not None."""
         assert self.__manager is not None
         return self.__manager
@@ -277,7 +279,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
 
     def set_link(
             self,
-            link: Optional[Callable[[], bool]],
+            link: Optional[types.link_t],
             update_style_procs: bool = True
     ) -> None:
         """Update node so that when it is clicked, link() -> bool is called.
@@ -396,18 +398,23 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
                 self.manager._set_updated(True)
             node._unref()
 
-    def set_animation(self, animation: 'Animation') -> None:
+    def set_animation(self, animation: Optional['Animation']) -> None:
         """Set and start an animation running on self.
 
         If an animation was already running on self it is stopped.
 
         """
-        if self.__animation is not None:
-            self.__animation.stop()
+        old_animation = self.__animation
         self.__animation = animation
+        if old_animation is not None:
+            old_animation.stop()
         if animation is not None:
             animation.start()
 
+    def stop_animation(self) -> None:
+        """Stop the animation set on self with set_animation."""
+        self.set_animation(None)
+
     def set_tooltip(
             self,
             tooltip: Node
@@ -484,15 +491,15 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             self.__manager._unref_node(self)
         self.__manager = None
 
-    def _set_manager(self, manager: Optional[EventManager]) -> None:
+    def _set_manager(self, manager: Optional[_EventManager]) -> None:
         if self.__manager == manager:
             return
         if self.__manager is not None:
             self.__manager._unref_node(self)
         self.__manager = manager
         if manager is not None:
-            for evt in self.__events:
-                for fun in self.__events[evt]:
+            for evt, funs in self.__events.items():
+                for fun in funs:
                     self.manager_._register(evt, self, fun)
 
     def _update_manager(self) -> None:
@@ -520,7 +527,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             #  size is expressed as a percentage of avail_size
             m = Node.__PERCENT_EXPR.fullmatch(val)
             if not m:
-                raise ValueError('could not parse size {}'.format(val))
+                raise ValueError(f'could not parse size {val}')
             percent = int(val[:len(val) - 1])
             result = int(avail * percent / 100)
             return result
@@ -589,7 +596,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             else:
                 Draw.rectangle_rounded(surface, bg_color, rect, corner)
         else:
-            raise ValueError('undefined background type: {}'.format(bg))
+            raise ValueError(f'undefined background type: {bg}')
 
     def __draw_border_images(
             self,
@@ -680,7 +687,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         elif border == 'color':
             self.__draw_border_color(surface, pos)
         elif border is not None:
-            raise ValueError('invalid border type: {}'.format(border))
+            raise ValueError(f'invalid border type: {border}')
 
     def draw(
             self,
@@ -743,7 +750,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
     ) -> Iterator[Node]:
         """Yield self and all its sub-tree.
 
-        If traverse is True, children nodes of EventManager nodes
+        If traverse is True, children nodes of _EventManager nodes
         inside self sub-tree are also traversed.
 
         """
@@ -845,7 +852,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         and its link is called (see help(pygwin.Node.__init__)).
 
         Return True if self has been activated, False otherwise (e.g.,
-        if its disabled or if its EventManager is not set.
+        if its disabled or if its _EventManager is not set.
 
         """
         if self.manager is None:
@@ -863,20 +870,23 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             return True
         return False
 
-    def add_processor(self, evt: str, proc: types.event_proc_t) -> None:
+    def add_processor(
+            self,
+            evt: types.event_t,
+            proc: types.event_proc_t
+    ) -> None:
         """Add processor function proc for event evt.
 
-        Event evt must be one of the Event enumeration ('on-activate',
-        'on-click-up', ...).  Function proc must have type
-        pg.event.Event -> bool.  It will be called each time event evt
-        will be triggered on self.  The pygame event parameter of the
-        function is the one that generated the pygwin event or None if
-        the pygwin event does not have an equivalent.  Function proc
-        must return True if the event has been handled.  This result
-        is used to determine if self's manager must be redrawned.
+        Function proc must have type pg.event.Event -> bool.  It will
+        be called each time event evt will be triggered on self.  The
+        pygame event parameter of the function is the one that
+        generated the pygwin event or None if the pygwin event does
+        not have an equivalent.  Function proc must return True if the
+        event has been handled.  This result is used to determine if
+        self's manager must be redrawned.
 
         """
-        if evt not in Event:
+        if evt not in types.all_events:
             logging.warning('event "%s" does not exist', evt)
         else:
             if evt not in self.__events:
@@ -885,7 +895,11 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             if self.__manager is not None:
                 self.__manager._register(evt, self, proc)
 
-    def del_processor(self, evt: str, proc: types.event_proc_t) -> None:
+    def del_processor(
+            self,
+            evt: types.event_t,
+            proc: types.event_proc_t
+    ) -> None:
         """Delete processor function proc for event evt.
 
         The method has no effect if the processor had not been
@@ -898,7 +912,7 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
 
     def get_style(
             self,
-            attr: str
+            attr: types.style_attr_t
     ) -> Any:
         """Get the style of self for attribute attr.
 
@@ -927,16 +941,16 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         except KeyError:
             pass
 
-        #  check if I have the attribute defined in one of my classes.
-        #  if so cache the result
+        #  check if self has the attribute defined in one of its
+        #  classes.  if so cache the result
         found, result = get(self)
         if found:
             self.__style_cache[attr] = result
             return result
 
-        #  for inherited attributes check if one of my parents has
+        #  for inherited attributes check if one of the ancestors has
         #  this attribute defined
-        if attr in Style.INHERITED:
+        if attr in INHERITED:
             parent = self.parent
             while parent is not None:
                 found, result = get(parent)
@@ -945,21 +959,25 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
                 parent = parent.parent
 
         #  in any other case, return the default style
-        self.__style_cache[attr] = Style.DEFAULT[attr]
-        return Style.DEFAULT[attr]
+        try:
+            self.__style_cache[attr] = DEFAULT[attr]
+            return self.__style_cache[attr]
+        except KeyError:
+            return None
 
     def set_style(
             self,
-            style: Dict[str, Any],
-            context: Optional[Dict[str, Any]] = None,
+            attr: types.style_attr_t,
+            value: Any,
+            context: Optional[types.sc_context_t] = None,
             cname: Optional[Any] = None,
             update: bool = True
     ) -> bool:
-        """Set the style of self for a specific context.
+        """Set the value of a style attribute for self.
 
-        If update is True, the style for the context is updated.
-        Otherwise if self already has a style for that context, the
-        method has no effect.
+        If update is True, the style attribute for the context is
+        updated.  Otherwise if self already has a style for that
+        context, the method has no effect.
 
         If cname is not None, then it must be one of the style classes
         of self.  Then this style class is updated.
@@ -967,12 +985,14 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         Return True if the style has been modified, False otherwise.
 
         >>> n = Node()
-        >>> n.set_style({'color': (0, 0, 255)})
+        >>> n.set_style('background', 'color')
         True
-        >>> n.set_style({'color': (255, 0, 0)}, context={'status': 'overed'})
+        >>> n.set_style('color', (0, 0, 255))
+        True
+        >>> n.set_style('color', (255, 0, 0), context={'status': 'overed'})
         True
         >>> n.set_style(
-        ...   {'color': (0, 255, 0)},
+        ...   'color', (0, 255, 0),
         ...   context={'status': 'overed'},
         ...   update=False
         ... )
@@ -986,13 +1006,12 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
 
         #  change the attribute in the class
         c = next(c for c in self.stc if c.name == cname)
-        if not c.add(Style(style), update=update, context=context):
+        if not c.add(attr, value, update=update, context=context):
             return False
 
         #  clear cache
-        for attr in style:
-            if attr in self.__style_cache:
-                del self.__style_cache[attr]
+        if attr in self.__style_cache:
+            del self.__style_cache[attr]
 
         self.__update_style_procs()
         self._reset_size()
@@ -1026,13 +1045,12 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         padding = self.get_style('padding')
         border = self.get_style('border')
         if border == 'image':
-            img = Media.get_image(self.get_style('border-images')[4])
-            assert img is not None
+            img = Media.get_image_(self.get_style('border-images')[4])
             border = img.get_height()
         elif border == 'color':
             border = self.get_style('border-width')
         elif border is not None:
-            raise ValueError('invalid border type: {}'.format(border))
+            raise ValueError(f'invalid border type: {border}')
         else:
             border = 0
         if isinstance(padding, int):
@@ -1082,18 +1100,39 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             font_size = int(mult * size)
         return Media.get_font_(font, size=font_size)
 
-    __STYLE_ANIMATIONS: Dict[str, Type[Animation]] = {
+    __STYLE_ANIMATIONS: Dict[types.animation_t, Type[Animation]] = {
         'fade': FadeAnimation,
         'fadein': FadeInAnimation,
         'fadeout': FadeOutAnimation,
+        'fill': FillAnimation,
         'glow': GlowAnimation,
         'grow': GrowAnimation,
+        'popin': PopInAnimation,
+        'popout': PopOutAnimation,
         'scroll': ScrollAnimation
     }
 
+    __STATUS_ON: Dict[types.status_t, types.event_t] = {
+        'base': 'on-open',
+        'clicked': 'on-clicked',
+        'disabled': 'on-disable',
+        'focus': 'on-focus',
+        'overed': 'on-over',
+        'selected': 'on-select'
+    }
+    __STATUS_OFF: Dict[types.status_t, types.event_t] = {
+        'base': 'on-close',
+        'clicked': 'on-unclicked',
+        'disabled': 'on-enable',
+        'focus': 'on-unfocus',
+        'overed': 'on-unover',
+        'selected': 'on-unselect'
+    }
+
     def __update_style_procs(self) -> None:
         def play_animation(
-                animation: Optional[str], animation_args: Dict[str, Any]
+                animation: Optional[types.animation_t],
+                animation_args: Dict[str, Any]
         ) -> bool:
             if animation is None:
                 return False
@@ -1124,12 +1163,12 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
             evt
             for c in self.stc
             for _, status in c._get_checked_status()
-            for evt in [Status.ON[status], Status.OFF[status]]
+            for evt in [Node.__STATUS_ON[status], Node.__STATUS_OFF[status]]
         }
         if any(c.does_check_value() for c in self.stc):
             changing_events.add('on-change')
         for evt in changing_events:
-            def change_style(_: str) -> Callable[[pg.event.Event], bool]:
+            def change_style(_: types.event_t) -> types.event_proc_t:
                 def do(_: pg.event.Event) -> bool:
                     return True
                 return do
@@ -1141,14 +1180,14 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
         for evt, pred, style in [
                 (evt, pred, style)
                 for c in self.stc
-                for evt in Event
+                for evt in types.all_events
                 for pred, style in c._iter_events(evt)
         ]:
             def handle_event(
-                    evt: str,
+                    evt: types.event_t,
                     pred: List[types.node_pred_t],
-                    style: Style
-            ) -> Callable[[pg.event.Event], bool]:
+                    style: types.style_t
+            ) -> types.event_proc_t:
                 def do(pgevt: pg.event.Event) -> bool:
                     if not all(pr(self) for pr in pred):
                         return False
@@ -1189,8 +1228,8 @@ class Node(metaclass=NodeType):  # pylint: disable=R0904,R0902
                     return True
                 return False
             for evt, fun in [
-                    (Status.ON[status], start),
-                    (Status.OFF[status], stop)
+                    (Node.__STATUS_ON[status], start),
+                    (Node.__STATUS_OFF[status], stop)
             ]:
                 self.add_processor(evt, fun)
                 self.__style_procs[evt].append(fun)
