@@ -33,13 +33,13 @@ def get_window(win_sys):
     box.pack(Label('right-click on a monster to open a contextual menu'))
     monsters = list()
     centered = {'halign': 'center'}
-    for m in glob.MONSTERS:
+    for m, mdata in glob.MONSTERS.items():
         monsters.append(m)
-        img = Image(Media.get_image(glob.MONSTERS[m][0], scale=(128, 128)))
+        img = Image(Media.get_image(mdata[0], scale=(128, 128)))
         menu = Box(
             Label('menu', style={'halign': 'center'}),
-            Label('delete {}'.format(m), link=delete(m), style=centered),
-            Label('show {}'.format(m), link=show(m), style=centered),
+            Label(f'delete {m}', link=delete(m), style=centered),
+            Label(f'show {m}', link=show(m), style=centered),
             Label('close', link=close(img), style=centered),
             style=glob.TOOLTIP_STYLE
         )
