@@ -20,14 +20,12 @@ the word wrong it.""",
     )
     cb = Checkbox()
     cb.set_style(
-        {'border-color': (0, 255, 0)},
+        'border-color', (0, 255, 0),
         context={'value': True}
     )
     it = InputText()
-    it.set_style(
-        {'background': 'color', 'background-color': (255, 0, 0)},
-        context={'value': 'wrong'}
-    )
+    it.set_style('background', 'color', context={'value': 'wrong'})
+    it.set_style('background-color', (255, 0, 0), context={'value': 'wrong'})
     return Window(
         win_sys,
         Box(board, cb, it, style={'size': ('100%', None)}),
