@@ -16,12 +16,10 @@ def get_window(win_sys):
     Cursor.activate()
     elf = Image(Media.get_image('elf.png', scale=(128, 128)))
     elf.set_style(
-        {'cursor-image': 'cursor-overed.png'},
-        context={'status': 'overed'}
+        'cursor-image', 'cursor-overed.png', context={'status': 'overed'}
     )
     elf.set_style(
-        {'cursor-image': 'cursor-clicked.png'},
-        context={'status': 'clicked'}
+        'cursor-image', 'cursor-clicked.png', context={'status': 'clicked'}
     )
     box = Box(
         Label('move over/click the image to change the cursor'),
