@@ -5,7 +5,8 @@
 import os
 
 from pygwin import Box, Label, Window, Table
-from pygwin import ItemSelect, Style
+from pygwin import ItemSelect
+from pygwin.style import DEFAULT
 from . import glob
 
 
@@ -15,15 +16,15 @@ TITLE = 'fonts'.title()
 def get_window(win_sys):
     """fonts window"""
     def change_name(_):
-        lbl.set_style({'font': name_select.value})
+        lbl.set_style('font', name_select.value)
         return True
 
     def change_size(_):
-        lbl.set_style({'font-size': size_select.value})
+        lbl.set_style('font-size', size_select.value)
         return True
     lbl = Label('hey, change my font!', style={'halign': 'center'})
     select = dict()
-    select[Style.DEFAULT['font']] = 'default'
+    select[DEFAULT['font']] = 'default'
     for f in os.listdir(glob.MEDIA_DIR):
         name, ext = os.path.splitext(f)
         if ext == '.ttf':
