@@ -16,7 +16,7 @@ def get_window(win_sys):
         m: glob.lorem_ipsum_textboard()
         for m in glob.MONSTERS
     }
-    for m in glob.MONSTERS:
+    for m, mdata in glob.MONSTERS.items():
         box = Box(
             glob.monster_table(m),
             boards[m],
@@ -26,7 +26,7 @@ def get_window(win_sys):
             box,
             style={'expand': True, 'size': ('100%', '100%')}
         )
-        img = Image(Media.get_image(glob.MONSTERS[m][0], scale=(64, 64)))
+        img = Image(Media.get_image(mdata[0], scale=(64, 64)))
         items[img] = frame
     node = Menu(items, style={'expand': True, 'size': ('100%', '100%')})
     return Window(
