@@ -12,9 +12,8 @@ TITLE = 'menus'.title()
 def get_window(win_sys):
     """menus window"""
     items = {
-        Image(Media.get_image(glob.MONSTERS[m][0], scale=(64, 64))):
-        glob.monster_table(m)
-        for m in glob.MONSTERS
+        Image(Media.get_image(mdata[0], scale=(64, 64))): glob.monster_table(m)
+        for m, mdata in glob.MONSTERS.items()
     }
     menu = Menu(items, style={'orientation': 'horizontal'})
     return Window(win_sys, menu, title=TITLE)
