@@ -24,10 +24,12 @@ def get_window(win_sys):
                  3: Label('max'),
                  4: Label('min'),
                  5: Label('max')})
-    for m in glob.MONSTERS:
-        cells = {j + 2: Label(data, style=right)
-                 for j, data in enumerate(glob.MONSTERS[m][1:])}
+    for m, mdata in glob.MONSTERS.items():
+        cells = {
+            j + 2: Label(data, style=right)
+            for j, data in enumerate(mdata[1:])
+        }
         cells[0] = Label(m)
-        cells[1] = Image(Media.get_image(glob.MONSTERS[m][0]))
+        cells[1] = Image(Media.get_image(mdata[0]))
         tbl.new_row(cells)
     return Window(win_sys, tbl, title=TITLE)
